@@ -7,7 +7,7 @@
 set -e
 
 # Refresh GNU autotools toolchain.
-for i in config.guess config.sub missing install-sh mkinstalldirs ; do
+for i in config.guess config.sub install-sh ; do
 	test -r /usr/share/automake/${i} && {
 		rm -f ${i}
 		cp /usr/share/automake/${i} .
