@@ -138,7 +138,7 @@ static int transform(int x, int y) {
 	return (int)(acc>=0? floor(acc+0.5) : ceil(acc-0.5) ) ;
 }
 
-static int getline(FILE *afmin) {
+static int afm_getline(FILE *afmin) {
 	char *p ;
 	int c ;
 
@@ -616,7 +616,7 @@ int readprotusion(PSDoc *psdoc, PSFont *psfont, const char *filename) {
 		return(-1);
 	}
 
-	while (getline(fp)) {
+	while (afm_getline(fp)) {
 		switch(interest(paramstring())) {
 			case N:
 				handleprotusion(psdoc, metrics) ;
@@ -646,6 +646,7 @@ ADOBEFONTMETRIC *readadobe(PSDoc *psdoc, const char *filename) {
 
 	if(0 == (metric->afmin = ps_open_file_in_path(psdoc, filename))) {
 		ps_error(psdoc, PS_RuntimeError, _("Couldn't open afm file: %s\n"), filename);
+		psdoc->free(psdoc, metric);
 		return(NULL);
 	}
 
@@ -664,7 +665,7 @@ ADOBEFONTMETRIC *readadobe(PSDoc *psdoc, const char *filename) {
 	/*
 	 * Read file line by line.
 	 */
-	while (getline(metric->afmin)) {
+	while (afm_getline(metric->afmin)) {
 		switch(interest(paramstring())) {
 case FontName:
 			metric->fontname = paramnewstring(psdoc) ;
@@ -1039,7 +1040,7 @@ static char *gettoken(PSDoc *psdoc, ADOBEFONTMETRIC *metrics) {
 
 	while (1) {
 		while (param == NULL || *param == '\0') {
-			if (getline(metrics->afmin) == 0)
+			if (afm_getline(metrics->afmin) == 0)
 				ps_error(psdoc, PS_RuntimeError, _("Premature end of encoding file."));
 			for (p=buffer; *p != '\0'; p++)
 				if (*p == '%') {
@@ -1160,7 +1161,7 @@ int readencoding(PSDoc *psdoc, ADOBEFONTMETRIC *metrics, const char *enc) {
 			psdoc->free(psdoc, e);
 			return -1;
 		}
-		while (getline(metrics->afmin)) {
+		while (afm_getline(metrics->afmin)) {
 			for (p=buffer; *p != '\0'; p++)
 				if (*p == '%') {
 					if (ignoreligkern == 0)
