@@ -81,7 +81,7 @@ PS_mp_realloc(PSDoc *p, void *mem, size_t size, const char *caller) {
 		i++;
 	}
 	if(i >= MAXMEM) {
-		fprintf(stderr, _("Aiii, did not find memory block at 0x%X to enlarge: %s"), (unsigned long) mem, caller);
+		fprintf(stderr, _("Aiii, did not find memory block at 0x%p to enlarge: %s"), mem, caller);
 		fprintf(stderr, "\n");
 	}
 	memlist[i].ptr = a;
@@ -107,7 +107,7 @@ PS_mp_free(PSDoc *p, void *mem) {
 		i++;
 	}
 	if(i >= MAXMEM) {
-		fprintf(stderr, _("Aiii, did not find memory block at 0x%X to free."), (unsigned long) mem);
+		fprintf(stderr, _("Aiii, did not find memory block at 0x%p to free."), mem);
 		fprintf(stderr, "\n");
 	} else {
 		memlist[i].ptr = NULL;
@@ -125,7 +125,7 @@ PS_mp_list_unfreed() {
 	i = j = 0;
 	while(i < MAXMEM) {
 		if(memlist[i].ptr) {
-			fprintf(stderr, _("%d. Memory at address 0x%X (%d) not freed: '%s'."), j, (unsigned long) memlist[i].ptr, memlist[i].size, memlist[i].caller);
+			fprintf(stderr, _("%d. Memory at address 0x%p (%d) not freed: '%s'."), j, memlist[i].ptr, memlist[i].size, memlist[i].caller);
 			ptr = memlist[i].ptr;
 			for(l=0; l<memlist[i].size; l++, ptr++) {
 				fputc(*ptr, stderr);
